Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(534)

Unified Diff: content/public/browser/security_style_explanations.h

Issue 2770703002: Rename SecurityStyleExplanations and WebSecurityStyle fields (Closed)
Patch Set: Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/public/browser/security_style_explanations.h
diff --git a/content/public/browser/security_style_explanations.h b/content/public/browser/security_style_explanations.h
index 3033c2a10a718495275b8db71a4fda8f8af3c9df..f7cc76302be375f8199baf967f7205807a71ee8f 100644
--- a/content/public/browser/security_style_explanations.h
+++ b/content/public/browser/security_style_explanations.h
@@ -23,8 +23,8 @@ namespace content {
// SecurityStyleExplanation is a single security property of a page (for
// example, an expired certificate, a valid certificate, or the presence
// of a deprecated crypto algorithm). A single site may have multiple
// different explanations of "secure", "warning", "broken", and "info" severity
// levels.
struct SecurityStyleExplanations {
CONTENT_EXPORT SecurityStyleExplanations();
CONTENT_EXPORT SecurityStyleExplanations(
@@ -69,11 +69,21 @@ struct SecurityStyleExplanations {
// the style cannot be determined from HTTPS status alone.
std::string summary;
- // Explanations corresponding to each security level. The embedder should
- // display explanations in the order: broken, unauthenticated, secure, info.
+ // Explanations corresponding to each security level.
estark 2017/03/22 17:32:27 (removed the instruction about how to display expl
+
+ // |secure_explanations| explains why the page was marked secure.
std::vector<SecurityStyleExplanation> secure_explanations;
- std::vector<SecurityStyleExplanation> unauthenticated_explanations;
- std::vector<SecurityStyleExplanation> broken_explanations;
+ // |neutral_explanations| explains why the page was marked neutrally: for
+ // example, the page's lock icon was taken away due to mixed content, or the
+ // page was not loaded over HTTPS.
+ std::vector<SecurityStyleExplanation> neutral_explanations;
+ // |insecure_explanations| explains why the page was marked as insecure or
+ // dangerous: for example, the page was loaded with a certificate error.
+ std::vector<SecurityStyleExplanation> insecure_explanations;
+ // |info_explanations| contains information that did not affect the page's
+ // security style, but is still relevant to the page's security state: for
+ // example, an upcoming deprecation that will affect the security style in
+ // future.
std::vector<SecurityStyleExplanation> info_explanations;
};
@@ -23,8 +23,8 @@ namespace content {
// example, an expired certificate, a valid certificate, or the presence
// of a deprecated crypto algorithm). A single site may have multiple
-// different explanations of "secure", "warning", "broken", and "info" severity
-// levels.
+// different explanations of "secure", "warning", "insecure", and "info"
+// severity levels.
struct SecurityStyleExplanations {
CONTENT_EXPORT SecurityStyleExplanations();

Powered by Google App Engine
This is Rietveld 408576698